Available sources
=================

Hardcoded defaults
------------------
.. autoclass:: layeredconfig.Defaults
  :members:
  :member-order: bysource

Environment variables
---------------------
		 
.. autoclass:: layeredconfig.Environment
  :members:
  :member-order: bysource

Command-line parameters
-----------------------
		 
.. autoclass:: layeredconfig.Commandline
  :members:
  :member-order: bysource

INI files
---------
		 
.. autoclass:: layeredconfig.INIFile
  :members:
  :member-order: bysource

JSON files
----------
		 
.. autoclass:: layeredconfig.JSONFile
  :members:
  :member-order: bysource

YAML files
----------
		 
.. autoclass:: layeredconfig.YAMLFile
  :members:
  :member-order: bysource

PList files
-----------
		 
.. autoclass:: layeredconfig.PListFile
  :members:
  :member-order: bysource

Python files
------------
		 
.. autoclass:: layeredconfig.PyFile
  :members:
  :member-order: bysource

``etcd`` stores
---------------

.. autoclass:: layeredconfig.EtcdStore
  :members:
  :member-order: bysource

